@@ -1,6 +1,9 @@
 from django.apps import AppConfig
+from django.core import checks
 from django.utils.translation import gettext_lazy as _
 
+from constance.checks import check_fieldsets
+
 
 class ConstanceConfig(AppConfig):
     name = 'constance'
@@ -8,5 +11,4 @@ class ConstanceConfig(AppConfig):
     default_auto_field = 'django.db.models.AutoField'
 
     def ready(self):
-        from . import checks
-
+        checks.register(check_fieldsets, 'constance')
