@@ -1,21 +1,20 @@
-from . import settings, utils
+from . import settings
+from . import utils
 
 
 class Config:
-    """
-    The global config wrapper that handles the backend.
-    """
+    """The global config wrapper that handles the backend."""
+
     def __init__(self):
-        super().__setattr__('_backend',
-            utils.import_module_attr(settings.BACKEND)())
+        super().__setattr__('_backend', utils.import_module_attr(settings.BACKEND)())
 
     def __getattr__(self, key):
         try:
-            if not len(settings.CONFIG[key]) in (2, 3):
+            if len(settings.CONFIG[key]) not in (2, 3):
                 raise AttributeError(key)
             default = settings.CONFIG[key][0]
-        except KeyError:
-            raise AttributeError(key)
+        except KeyError as e:
+            raise AttributeError(key) from e
         result = self._backend.get(key)
         if result is None:
             result = default
