@@ -1,9 +1,8 @@
-from django.db import migrations, models
-import picklefield.fields
+from django.db import migrations
+from django.db import models
 
 
 class Migration(migrations.Migration):
-
     initial = True
 
     dependencies = []
@@ -14,7 +13,7 @@ class Migration(migrations.Migration):
             fields=[
                 ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                 ('key', models.CharField(max_length=255, unique=True)),
-                ('value', picklefield.fields.PickledObjectField(blank=True, editable=False, null=True)),
+                ('value', models.TextField(blank=True, editable=False, null=True)),
             ],
             options={
                 'verbose_name': 'constance',
