@@ -5,7 +5,6 @@ from tests.storage import StorageTestsMixin
 
 
 class TestDatabase(StorageTestsMixin, TestCase):
-
     def setUp(self):
         self.old_backend = settings.BACKEND
         settings.BACKEND = 'constance.backends.database.DatabaseBackend'
@@ -14,11 +13,11 @@ class TestDatabase(StorageTestsMixin, TestCase):
     def test_database_queries(self):
         # Read and set to default value
         with self.assertNumQueries(5):
-            self.config.INT_VALUE
+            self.assertEqual(self.config.INT_VALUE, 1)
 
         # Read again
         with self.assertNumQueries(1):
-            self.config.INT_VALUE
+            self.assertEqual(self.config.INT_VALUE, 1)
 
         # Set value
         with self.assertNumQueries(2):
